@@ -3,7 +3,7 @@ use uv_pypi_types::RequirementSource;
 use uv_normalize::PackageName;
 
 use crate::resolver::ForkSet;
-use crate::{DependencyMode, Manifest, ResolverMarkers};
+use crate::{DependencyMode, Manifest, ResolverEnvironment};
 
 #[derive(Debug, Default, Clone, Copy, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
 #[serde(deny_unknown_fields, rename_all = "kebab-case")]
@@ -67,7 +67,7 @@ impl PrereleaseStrategy {
     pub(crate) fn from_mode(
         mode: PrereleaseMode,
         manifest: &Manifest,
-        markers: &ResolverMarkers,
+        env: &ResolverEnvironment,
         dependencies: DependencyMode,
     ) -> Self {
         let mut packages = ForkSet::default();
@@ -77,7 +77,7 @@ impl PrereleaseStrategy {
             PrereleaseMode::Allow => Self::Allow,
             PrereleaseMode::IfNecessary => Self::IfNecessary,
             _ => {
-                for requirement in manifest.requirements(markers, dependencies) {
+                for requirement in manifest.requirements(env, dependencies) {
                     let RequirementSource::Registry { specifier, .. } = &requirement.source else {
                         continue;
                     };
@@ -103,21 +103,21 @@ impl PrereleaseStrategy {
     pub(crate) fn allows(
         &self,
         package_name: &PackageName,
-        markers: &ResolverMarkers,
+        env: &ResolverEnvironment,
     ) -> AllowPrerelease {
         match self {
             PrereleaseStrategy::Disallow => AllowPrerelease::No,
             PrereleaseStrategy::Allow => AllowPrerelease::Yes,
             PrereleaseStrategy::IfNecessary => AllowPrerelease::IfNecessary,
             PrereleaseStrategy::Explicit(packages) => {
-                if packages.contains(package_name, markers) {
+                if packages.contains(package_name, env) {
                     AllowPrerelease::Yes
                 } else {
                     AllowPrerelease::No
                 }
             }
             PrereleaseStrategy::IfNecessaryOrExplicit(packages) => {
-                if packages.contains(package_name, markers) {
+                if packages.contains(package_name, env) {
                     AllowPrerelease::Yes
                 } else {
                     AllowPrerelease::IfNecessary
