@@ -2,7 +2,7 @@ use rustc_hash::FxHashMap;
 use uv_pep508::{MarkerTree, PackageName};
 use uv_pypi_types::Requirement;
 
-use crate::ResolverMarkers;
+use crate::ResolverEnvironment;
 
 /// A set of package names associated with a given fork.
 pub(crate) type ForkSet = ForkMap<()>;
@@ -40,8 +40,8 @@ impl<T> ForkMap<T> {
 
     /// Returns `true` if the map contains any values for a package that are compatible with the
     /// given fork.
-    pub(crate) fn contains(&self, package_name: &PackageName, markers: &ResolverMarkers) -> bool {
-        !self.get(package_name, markers).is_empty()
+    pub(crate) fn contains(&self, package_name: &PackageName, env: &ResolverEnvironment) -> bool {
+        !self.get(package_name, env).is_empty()
     }
 
     /// Returns `true` if the map contains any values for a package.
@@ -54,30 +54,14 @@ impl<T> ForkMap<T> {
     /// Compatibility implies that the markers on the requirement that contained this value
     /// are not disjoint with the given fork. Note that this does not imply that the requirement
     /// diverged in the given fork - values from overlapping forks may be combined.
-    pub(crate) fn get(&self, package_name: &PackageName, markers: &ResolverMarkers) -> Vec<&T> {
+    pub(crate) fn get(&self, package_name: &PackageName, env: &ResolverEnvironment) -> Vec<&T> {
         let Some(values) = self.0.get(package_name) else {
             return Vec::new();
         };
-
-        match markers {
-            // If we are solving for a specific environment we already filtered
-            // compatible requirements `from_manifest`.
-            ResolverMarkers::SpecificEnvironment(_) => values
-                .first()
-                .map(|entry| &entry.value)
-                .into_iter()
-                .collect(),
-
-            // Return all values that were requested with markers that are compatible
-            // with the current fork, i.e. the markers are not disjoint.
-            ResolverMarkers::Fork(fork) => values
-                .iter()
-                .filter(|entry| !fork.is_disjoint(&entry.marker))
-                .map(|entry| &entry.value)
-                .collect(),
-
-            // If we haven't forked yet, all values are potentially compatible.
-            ResolverMarkers::Universal { .. } => values.iter().map(|entry| &entry.value).collect(),
-        }
+        values
+            .iter()
+            .filter(|entry| env.included(&entry.marker))
+            .map(|entry| &entry.value)
+            .collect()
     }
 }
