@@ -32,13 +32,13 @@ use uv_requirements::upgrade::{read_lock_requirements, LockedRequirements};
 use uv_requirements::{NamedRequirementsResolver, RequirementsSpecification};
 use uv_resolver::{
     FlatIndex, Lock, OptionsBuilder, PythonRequirement, RequiresPython, ResolutionGraph,
-    ResolverMarkers,
+    ResolverEnvironment,
 };
 use uv_types::{BuildIsolation, EmptyInstalledPackages, HashStrategy};
 use uv_warnings::{warn_user, warn_user_once};
 use uv_workspace::dependency_groups::DependencyGroupError;
 use uv_workspace::pyproject::PyProjectToml;
-use uv_workspace::Workspace;
+use uv_workspace::{ProjectWorkspace, Workspace};
 
 use crate::commands::pip::loggers::{InstallLogger, ResolveLogger};
 use crate::commands::pip::operations::{Changelog, Modifications};
@@ -126,7 +126,10 @@ pub(crate) enum ProjectError {
     ),
 
     #[error("Group `{0}` is not defined in the project's `dependency-group` table")]
-    MissingGroup(GroupName),
+    MissingGroupProject(GroupName),
+
+    #[error("Group `{0}` is not defined in any project's `dependency-group` table")]
+    MissingGroupWorkspace(GroupName),
 
     #[error("Default group `{0}` (from `tool.uv.default-groups`) is not defined in the project's `dependency-group` table")]
     MissingDefaultGroup(GroupName),
@@ -176,9 +179,6 @@ pub(crate) enum ProjectError {
     #[error(transparent)]
     Operation(#[from] pip::operations::Error),
 
-    #[error(transparent)]
-    RequiresPython(#[from] uv_resolver::RequiresPythonError),
-
     #[error(transparent)]
     Interpreter(#[from] uv_python::InterpreterError),
 
@@ -208,9 +208,7 @@ pub(crate) enum ProjectError {
 ///
 /// For a [`Workspace`] with multiple packages, the `Requires-Python` bound is the union of the
 /// `Requires-Python` bounds of all the packages.
-pub(crate) fn find_requires_python(
-    workspace: &Workspace,
-) -> Result<Option<RequiresPython>, uv_resolver::RequiresPythonError> {
+pub(crate) fn find_requires_python(workspace: &Workspace) -> Option<RequiresPython> {
     RequiresPython::intersection(workspace.packages().values().filter_map(|member| {
         member
             .pyproject_toml()
@@ -341,7 +339,7 @@ impl WorkspacePython {
         python_request: Option<PythonRequest>,
         workspace: &Workspace,
     ) -> Result<Self, ProjectError> {
-        let requires_python = find_requires_python(workspace)?;
+        let requires_python = find_requires_python(workspace);
 
         let (source, python_request) = if let Some(request) = python_request {
             // (1) Explicit request from user
@@ -815,7 +813,7 @@ pub(crate) async fn resolve_environment<'a>(
 
     // Determine the tags, markers, and interpreter to use for resolution.
     let tags = interpreter.tags()?;
-    let markers = interpreter.resolver_markers();
+    let marker_env = interpreter.resolver_marker_environment();
     let python_requirement = PythonRequirement::from_interpreter(interpreter);
 
     // Add all authenticated sources to the cache.
@@ -931,7 +929,7 @@ pub(crate) async fn resolve_environment<'a>(
         &reinstall,
         &upgrade,
         Some(tags),
-        ResolverMarkers::specific_environment(markers),
+        ResolverEnvironment::specific(marker_env),
         python_requirement,
         &client,
         &flat_index,
@@ -1145,12 +1143,12 @@ pub(crate) async fn update_environment(
 
     // Determine markers to use for resolution.
     let interpreter = venv.interpreter();
-    let markers = venv.interpreter().resolver_markers();
+    let marker_env = venv.interpreter().resolver_marker_environment();
 
     // Check if the current environment satisfies the requirements
     let site_packages = SitePackages::from_environment(&venv)?;
     if source_trees.is_empty() && reinstall.is_none() && upgrade.is_none() && overrides.is_empty() {
-        match site_packages.satisfies(&requirements, &constraints, &markers)? {
+        match site_packages.satisfies(&requirements, &constraints, &marker_env)? {
             // If the requirements are already satisfied, we're done.
             SatisfiesResult::Fresh {
                 recursive_requirements,
@@ -1273,7 +1271,7 @@ pub(crate) async fn update_environment(
         reinstall,
         upgrade,
         Some(tags),
-        ResolverMarkers::specific_environment(markers.clone()),
+        ResolverEnvironment::specific(marker_env.clone()),
         python_requirement,
         &client,
         &flat_index,
@@ -1368,26 +1366,46 @@ pub(crate) async fn script_python_requirement(
     ))
 }
 
-/// Validate the dependency groups requested by the [`DevGroupsSpecification`].
-#[allow(clippy::result_large_err)]
-pub(crate) fn validate_dependency_groups(
-    pyproject_toml: &PyProjectToml,
-    dev: &DevGroupsSpecification,
-) -> Result<(), ProjectError> {
-    for group in dev
-        .groups()
-        .into_iter()
-        .flat_map(GroupsSpecification::names)
-    {
-        if !pyproject_toml
-            .dependency_groups
-            .as_ref()
-            .is_some_and(|groups| groups.contains_key(group))
+#[derive(Debug, Copy, Clone)]
+pub(crate) enum DependencyGroupsTarget<'env> {
+    /// The dependency groups can be defined in any workspace member.
+    Workspace(&'env Workspace),
+    /// The dependency groups must be defined in the target project.
+    Project(&'env ProjectWorkspace),
+}
+
+impl DependencyGroupsTarget<'_> {
+    /// Validate the dependency groups requested by the [`DevGroupsSpecification`].
+    #[allow(clippy::result_large_err)]
+    pub(crate) fn validate(self, dev: &DevGroupsSpecification) -> Result<(), ProjectError> {
+        for group in dev
+            .groups()
+            .into_iter()
+            .flat_map(GroupsSpecification::names)
         {
-            return Err(ProjectError::MissingGroup(group.clone()));
+            match self {
+                Self::Workspace(workspace) => {
+                    // The group must be defined in the workspace.
+                    if !workspace.groups().contains(group) {
+                        return Err(ProjectError::MissingGroupWorkspace(group.clone()));
+                    }
+                }
+                Self::Project(project) => {
+                    // The group must be defined in the target project.
+                    if !project
+                        .current_project()
+                        .pyproject_toml()
+                        .dependency_groups
+                        .as_ref()
+                        .is_some_and(|groups| groups.contains_key(group))
+                    {
+                        return Err(ProjectError::MissingGroupProject(group.clone()));
+                    }
+                }
+            }
         }
+        Ok(())
     }
-    Ok(())
 }
 
 /// Returns the default dependency groups from the [`PyProjectToml`].
