@@ -31,11 +31,11 @@ use uv_python::{
     PythonPreference, PythonRequest, PythonVariant, PythonVersionFile, VersionRequest,
 };
 use uv_requirements::{RequirementsSource, RequirementsSpecification};
-use uv_resolver::Lock;
+use uv_resolver::{InstallTarget, Lock};
 use uv_scripts::Pep723Item;
 use uv_static::EnvVars;
 use uv_warnings::warn_user;
-use uv_workspace::{DiscoveryOptions, InstallTarget, VirtualProject, Workspace, WorkspaceError};
+use uv_workspace::{DiscoveryOptions, VirtualProject, Workspace, WorkspaceError};
 
 use crate::commands::pip::loggers::{
     DefaultInstallLogger, DefaultResolveLogger, SummaryInstallLogger, SummaryResolveLogger,
@@ -45,7 +45,7 @@ use crate::commands::pip::operations::Modifications;
 use crate::commands::project::environment::CachedEnvironment;
 use crate::commands::project::lock::LockMode;
 use crate::commands::project::{
-    default_dependency_groups, validate_dependency_groups, validate_requires_python,
+    default_dependency_groups, validate_requires_python, DependencyGroupsTarget,
     EnvironmentSpecification, ProjectError, PythonRequestSource, WorkspacePython,
 };
 use crate::commands::reporters::PythonDownloadReporter;
@@ -65,6 +65,7 @@ pub(crate) async fn run(
     frozen: bool,
     no_sync: bool,
     isolated: bool,
+    all_packages: bool,
     package: Option<PackageName>,
     no_project: bool,
     no_config: bool,
@@ -80,6 +81,8 @@ pub(crate) async fn run(
     native_tls: bool,
     cache: &Cache,
     printer: Printer,
+    env_file: Vec<PathBuf>,
+    no_env_file: bool,
 ) -> anyhow::Result<ExitStatus> {
     // These cases seem quite complex because (in theory) they should change the "current package".
     // Let's ban them entirely for now.
@@ -106,6 +109,44 @@ pub(crate) async fn run(
     // Initialize any shared state.
     let state = SharedState::default();
 
+    // Read from the `.env` file, if necessary.
+    if !no_env_file {
+        for env_file_path in env_file.iter().rev().map(PathBuf::as_path) {
+            match dotenvy::from_path(env_file_path) {
+                Err(dotenvy::Error::Io(err)) if err.kind() == std::io::ErrorKind::NotFound => {
+                    bail!(
+                        "No environment file found at: `{}`",
+                        env_file_path.simplified_display()
+                    );
+                }
+                Err(dotenvy::Error::Io(err)) => {
+                    bail!(
+                        "Failed to read environment file `{}`: {err}",
+                        env_file_path.simplified_display()
+                    );
+                }
+                Err(dotenvy::Error::LineParse(content, position)) => {
+                    warn_user!(
+                        "Failed to parse environment file `{}` at position {position}: {content}",
+                        env_file_path.simplified_display(),
+                    );
+                }
+                Err(err) => {
+                    warn_user!(
+                        "Failed to parse environment file `{}`: {err}",
+                        env_file_path.simplified_display(),
+                    );
+                }
+                Ok(()) => {
+                    debug!(
+                        "Read environment file at: `{}`",
+                        env_file_path.simplified_display()
+                    );
+                }
+            }
+        }
+    }
+
     // Initialize any output reporters.
     let download_reporter = PythonDownloadReporter::single(printer);
 
@@ -346,6 +387,11 @@ pub(crate) async fn run(
         if let Some(flag) = dev.groups().and_then(GroupsSpecification::as_flag) {
             warn_user!("`{flag}` is not supported for Python scripts with inline metadata");
         }
+        if all_packages {
+            warn_user!(
+                "`--all-packages` is a no-op for Python scripts with inline metadata, which always run in isolation"
+            );
+        }
         if package.is_some() {
             warn_user!(
                 "`--package` is a no-op for Python scripts with inline metadata, which always run in isolation"
@@ -550,8 +596,24 @@ pub(crate) async fn run(
                         .flatten();
                 }
             } else {
+                // Validate that any referenced dependency groups are defined in the workspace.
+                if !frozen {
+                    let target = match &project {
+                        VirtualProject::Project(project) => {
+                            if all_packages {
+                                DependencyGroupsTarget::Workspace(project.workspace())
+                            } else {
+                                DependencyGroupsTarget::Project(project)
+                            }
+                        }
+                        VirtualProject::NonProject(workspace) => {
+                            DependencyGroupsTarget::Workspace(workspace)
+                        }
+                    };
+                    target.validate(&dev)?;
+                }
+
                 // Determine the default groups to include.
-                validate_dependency_groups(project.pyproject_toml(), &dev)?;
                 let defaults = default_dependency_groups(project.pyproject_toml())?;
 
                 // Determine the lock mode.
@@ -604,12 +666,33 @@ pub(crate) async fn run(
                     Err(err) => return Err(err.into()),
                 };
 
+                // Identify the installation target.
+                let target = match &project {
+                    VirtualProject::Project(project) => {
+                        if all_packages {
+                            InstallTarget::Workspace {
+                                workspace: project.workspace(),
+                                lock: result.lock(),
+                            }
+                        } else {
+                            InstallTarget::Project {
+                                workspace: project.workspace(),
+                                name: project.project_name(),
+                                lock: result.lock(),
+                            }
+                        }
+                    }
+                    VirtualProject::NonProject(workspace) => InstallTarget::NonProjectWorkspace {
+                        workspace,
+                        lock: result.lock(),
+                    },
+                };
+
                 let install_options = InstallOptions::default();
 
                 project::sync::do_sync(
-                    InstallTarget::from(&project),
+                    target,
                     &venv,
-                    result.lock(),
                     &extras,
                     &dev.with_defaults(defaults),
                     editable,
@@ -966,7 +1049,7 @@ fn can_skip_ephemeral(
     match site_packages.satisfies(
         &spec.requirements,
         &spec.constraints,
-        &base_interpreter.resolver_markers(),
+        &base_interpreter.resolver_marker_environment(),
     ) {
         // If the requirements are already satisfied, we're done.
         Ok(SatisfiesResult::Fresh {
