@@ -1,6 +1,7 @@
 use std::{collections::BTreeSet, fmt::Write};
 
 use anyhow::Result;
+use itertools::Itertools;
 use owo_colors::OwoColorize;
 use tracing::debug;
 
@@ -95,9 +96,7 @@ pub(crate) async fn upgrade(
     // Determine whether we applied any upgrades.
     let mut did_upgrade_environment = vec![];
 
-    // Determine whether any tool upgrade failed.
-    let mut failed_upgrade = false;
-
+    let mut errors = Vec::new();
     for name in &names {
         debug!("Upgrading tool: `{name}`");
         let result = upgrade_tool(
@@ -125,22 +124,31 @@ pub(crate) async fn upgrade(
                 debug!("Upgrading `{name}` was a no-op");
             }
             Err(err) => {
-                // If we have a single tool, return the error directly.
-                if names.len() > 1 {
-                    writeln!(
-                        printer.stderr(),
-                        "Failed to upgrade `{}`: {err}",
-                        name.cyan(),
-                    )?;
-                } else {
-                    writeln!(printer.stderr(), "{err}")?;
-                }
-                failed_upgrade = true;
+                errors.push((name, err));
             }
         }
     }
 
-    if failed_upgrade {
+    if !errors.is_empty() {
+        for (name, err) in errors
+            .into_iter()
+            .sorted_unstable_by(|(name_a, _), (name_b, _)| name_a.cmp(name_b))
+        {
+            writeln!(
+                printer.stderr(),
+                "{}: Failed to upgrade {}",
+                "error".red().bold(),
+                name.green()
+            )?;
+            for err in err.chain() {
+                writeln!(
+                    printer.stderr(),
+                    "  {}: {}",
+                    "Caused by".red().bold(),
+                    err.to_string().trim()
+                )?;
+            }
+        }
         return Ok(ExitStatus::Failure);
     }
 
