@@ -32,7 +32,7 @@ use uv_static::EnvVars;
 // Exclude any packages uploaded after this date.
 static EXCLUDE_NEWER: &str = "2024-03-25T00:00:00Z";
 
-pub const PACKSE_VERSION: &str = "0.3.37";
+pub const PACKSE_VERSION: &str = "0.3.39";
 
 /// Using a find links url allows using `--index-url` instead of `--extra-index-url` in tests
 /// to prevent dependency confusion attacks against our test suite.
@@ -76,6 +76,7 @@ pub const INSTA_FILTERS: &[(&str, &str)] = &[
 /// * Set a cutoff for versions used in the resolution so the snapshots don't change after a new release.
 /// * Set the venv to a fresh `.venv` in `temp_dir`
 pub struct TestContext {
+    pub root: ChildPath,
     pub temp_dir: ChildPath,
     pub cache_dir: ChildPath,
     pub python_dir: ChildPath,
@@ -214,8 +215,9 @@ impl TestContext {
 
     /// Adds a filter that ignores platform information in a Python installation key.
     pub fn with_filtered_python_keys(mut self) -> Self {
+        // Filter platform keys
         self.filters.push((
-            r"((?:cpython|pypy)-\d+\.\d+(:?\.\d+)?[a-z]?(:?\+[a-z]+)?)-.*".to_string(),
+            r"((?:cpython|pypy)-\d+\.\d+(?:\.(?:\[X\]|\d+))?[a-z]?(?:\+[a-z]+)?)-.*".to_string(),
             "$1-[PLATFORM]".to_string(),
         ));
         self
@@ -425,6 +427,7 @@ impl TestContext {
         ));
 
         Self {
+            root: ChildPath::new(root.path()),
             temp_dir,
             cache_dir,
             python_dir,
@@ -440,7 +443,7 @@ impl TestContext {
 
     /// Create a uv command for testing.
     pub fn command(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         self.add_shared_args(&mut command, true);
         command
     }
@@ -475,7 +478,7 @@ impl TestContext {
 
         if cfg!(unix) {
             // Avoid locale issues in tests
-            command.env("LC_ALL", "C");
+            command.env(EnvVars::LC_ALL, "C");
         }
 
         if cfg!(all(windows, debug_assertions)) {
@@ -487,7 +490,7 @@ impl TestContext {
 
     /// Create a `pip compile` command for testing.
     pub fn pip_compile(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("compile");
         self.add_shared_args(&mut command, true);
         command
@@ -495,14 +498,14 @@ impl TestContext {
 
     /// Create a `pip compile` command for testing.
     pub fn pip_sync(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("sync");
         self.add_shared_args(&mut command, true);
         command
     }
 
     pub fn pip_show(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("show");
         self.add_shared_args(&mut command, true);
         command
@@ -510,7 +513,7 @@ impl TestContext {
 
     /// Create a `pip freeze` command with options shared across scenarios.
     pub fn pip_freeze(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("freeze");
         self.add_shared_args(&mut command, true);
         command
@@ -518,14 +521,14 @@ impl TestContext {
 
     /// Create a `pip check` command with options shared across scenarios.
     pub fn pip_check(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("check");
         self.add_shared_args(&mut command, true);
         command
     }
 
     pub fn pip_list(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("list");
         self.add_shared_args(&mut command, true);
         command
@@ -533,7 +536,7 @@ impl TestContext {
 
     /// Create a `uv venv` command
     pub fn venv(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("venv");
         self.add_shared_args(&mut command, false);
         command
@@ -541,7 +544,7 @@ impl TestContext {
 
     /// Create a `pip install` command with options shared across scenarios.
     pub fn pip_install(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("install");
         self.add_shared_args(&mut command, true);
         command
@@ -549,7 +552,7 @@ impl TestContext {
 
     /// Create a `pip uninstall` command with options shared across scenarios.
     pub fn pip_uninstall(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("uninstall");
         self.add_shared_args(&mut command, true);
         command
@@ -557,7 +560,7 @@ impl TestContext {
 
     /// Create a `pip tree` command for testing.
     pub fn pip_tree(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("pip").arg("tree");
         self.add_shared_args(&mut command, true);
         command
@@ -566,7 +569,7 @@ impl TestContext {
     /// Create a `uv help` command with options shared across scenarios.
     #[allow(clippy::unused_self)]
     pub fn help(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("help");
         command.env_remove(EnvVars::UV_CACHE_DIR);
 
@@ -579,9 +582,10 @@ impl TestContext {
         command
     }
 
-    /// Create a `uv init` command with options shared across scenarios.
+    /// Create a `uv init` command with options shared across scenarios and
+    /// isolated from any git repository that may exist in a parent directory.
     pub fn init(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("init");
         self.add_shared_args(&mut command, false);
         command
@@ -589,7 +593,7 @@ impl TestContext {
 
     /// Create a `uv sync` command with options shared across scenarios.
     pub fn sync(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("sync");
         self.add_shared_args(&mut command, false);
         command
@@ -597,7 +601,7 @@ impl TestContext {
 
     /// Create a `uv lock` command with options shared across scenarios.
     pub fn lock(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("lock");
         self.add_shared_args(&mut command, false);
         command
@@ -605,7 +609,7 @@ impl TestContext {
 
     /// Create a `uv export` command with options shared across scenarios.
     pub fn export(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("export");
         self.add_shared_args(&mut command, false);
         command
@@ -613,16 +617,15 @@ impl TestContext {
 
     /// Create a `uv build` command with options shared across scenarios.
     pub fn build(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("build");
         self.add_shared_args(&mut command, false);
         command
     }
 
     /// Create a `uv publish` command with options shared across scenarios.
-    #[expect(clippy::unused_self)] // For consistency
     pub fn publish(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("publish");
 
         if cfg!(all(windows, debug_assertions)) {
@@ -636,7 +639,7 @@ impl TestContext {
 
     /// Create a `uv python find` command with options shared across scenarios.
     pub fn python_find(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command
             .arg("python")
             .arg("find")
@@ -649,33 +652,44 @@ impl TestContext {
 
     /// Create a `uv python install` command with options shared across scenarios.
     pub fn python_install(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         let managed = self.temp_dir.join("managed");
+        let bin = self.temp_dir.join("bin");
         self.add_shared_args(&mut command, true);
         command
             .arg("python")
             .arg("install")
             .env(EnvVars::UV_PYTHON_INSTALL_DIR, managed)
+            .env(EnvVars::UV_PYTHON_BIN_DIR, bin.as_os_str())
+            .env(
+                EnvVars::PATH,
+                std::env::join_paths(std::iter::once(bin).chain(std::env::split_paths(
+                    &env::var(EnvVars::PATH).unwrap_or_default(),
+                )))
+                .unwrap(),
+            )
             .current_dir(&self.temp_dir);
         command
     }
 
     /// Create a `uv python uninstall` command with options shared across scenarios.
     pub fn python_uninstall(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         let managed = self.temp_dir.join("managed");
+        let bin = self.temp_dir.join("bin");
         self.add_shared_args(&mut command, true);
         command
             .arg("python")
             .arg("uninstall")
             .env(EnvVars::UV_PYTHON_INSTALL_DIR, managed)
+            .env(EnvVars::UV_PYTHON_BIN_DIR, bin)
             .current_dir(&self.temp_dir);
         command
     }
 
     /// Create a `uv python pin` command with options shared across scenarios.
     pub fn python_pin(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("python").arg("pin");
         self.add_shared_args(&mut command, true);
         command
@@ -683,7 +697,7 @@ impl TestContext {
 
     /// Create a `uv python dir` command with options shared across scenarios.
     pub fn python_dir(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("python").arg("dir");
         self.add_shared_args(&mut command, true);
         command
@@ -691,7 +705,7 @@ impl TestContext {
 
     /// Create a `uv run` command with options shared across scenarios.
     pub fn run(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("run").env(EnvVars::UV_SHOW_RESOLUTION, "1");
         self.add_shared_args(&mut command, true);
         command
@@ -699,7 +713,7 @@ impl TestContext {
 
     /// Create a `uv tool run` command with options shared across scenarios.
     pub fn tool_run(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command
             .arg("tool")
             .arg("run")
@@ -710,7 +724,7 @@ impl TestContext {
 
     /// Create a `uv upgrade run` command with options shared across scenarios.
     pub fn tool_upgrade(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("tool").arg("upgrade");
         self.add_shared_args(&mut command, false);
         command
@@ -718,7 +732,7 @@ impl TestContext {
 
     /// Create a `uv tool install` command with options shared across scenarios.
     pub fn tool_install(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("tool").arg("install");
         self.add_shared_args(&mut command, false);
         command.env(EnvVars::UV_EXCLUDE_NEWER, EXCLUDE_NEWER);
@@ -727,7 +741,7 @@ impl TestContext {
 
     /// Create a `uv tool list` command with options shared across scenarios.
     pub fn tool_list(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("tool").arg("list");
         self.add_shared_args(&mut command, false);
         command
@@ -735,7 +749,7 @@ impl TestContext {
 
     /// Create a `uv tool dir` command with options shared across scenarios.
     pub fn tool_dir(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("tool").arg("dir");
         self.add_shared_args(&mut command, false);
         command
@@ -743,7 +757,7 @@ impl TestContext {
 
     /// Create a `uv tool uninstall` command with options shared across scenarios.
     pub fn tool_uninstall(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("tool").arg("uninstall");
         self.add_shared_args(&mut command, false);
         command
@@ -751,7 +765,7 @@ impl TestContext {
 
     /// Create a `uv add` command for the given requirements.
     pub fn add(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("add");
         self.add_shared_args(&mut command, false);
         command
@@ -759,7 +773,7 @@ impl TestContext {
 
     /// Create a `uv remove` command for the given requirements.
     pub fn remove(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("remove");
         self.add_shared_args(&mut command, false);
         command
@@ -767,7 +781,7 @@ impl TestContext {
 
     /// Create a `uv tree` command with options shared across scenarios.
     pub fn tree(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("tree");
         self.add_shared_args(&mut command, false);
         command
@@ -775,7 +789,7 @@ impl TestContext {
 
     /// Create a `uv cache clean` command.
     pub fn clean(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("cache").arg("clean");
         self.add_shared_args(&mut command, false);
         command
@@ -783,7 +797,7 @@ impl TestContext {
 
     /// Create a `uv cache prune` command.
     pub fn prune(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("cache").arg("prune");
         self.add_shared_args(&mut command, false);
         command
@@ -793,7 +807,7 @@ impl TestContext {
     ///
     /// Note that this command is hidden and only invoking it through a build frontend is supported.
     pub fn build_backend(&self) -> Command {
-        let mut command = Command::new(get_bin());
+        let mut command = self.new_command();
         command.arg("build-backend");
         self.add_shared_args(&mut command, false);
         command
@@ -805,7 +819,7 @@ impl TestContext {
 
     /// Run the given python code and check whether it succeeds.
     pub fn assert_command(&self, command: &str) -> Assert {
-        Command::new(venv_to_interpreter(&self.venv))
+        self.new_command_with(&venv_to_interpreter(&self.venv))
             // Our tests change files in <1s, so we must disable CPython bytecode caching or we'll get stale files
             // https://github.com/python/cpython/issues/75953
             .arg("-B")
@@ -817,7 +831,7 @@ impl TestContext {
 
     /// Run the given python file and check whether it succeeds.
     pub fn assert_file(&self, file: impl AsRef<Path>) -> Assert {
-        Command::new(venv_to_interpreter(&self.venv))
+        self.new_command_with(&venv_to_interpreter(&self.venv))
             // Our tests change files in <1s, so we must disable CPython bytecode caching or we'll get stale files
             // https://github.com/python/cpython/issues/75953
             .arg("-B")
@@ -977,6 +991,33 @@ impl TestContext {
         fs_err::read_to_string(self.temp_dir.join(&file))
             .unwrap_or_else(|_| panic!("Missing file: `{}`", file.user_display()))
     }
+
+    /// Creates a new `Command` that is intended to be suitable for use in
+    /// all tests.
+    fn new_command(&self) -> Command {
+        self.new_command_with(&get_bin())
+    }
+
+    /// Creates a new `Command` that is intended to be suitable for use in
+    /// all tests, but with the given binary.
+    fn new_command_with(&self, bin: &Path) -> Command {
+        let mut command = Command::new(bin);
+        // I believe the intent of all tests is that they are run outside the
+        // context of an existing git repository. And when they aren't, state
+        // from the parent git repository can bleed into the behavior of `uv
+        // init` in a way that makes it difficult to test consistently. By
+        // setting GIT_CEILING_DIRECTORIES, we specifically prevent git from
+        // climbing up past the root of our test directory to look for any
+        // other git repos.
+        //
+        // If one wants to write a test specifically targeting uv within a
+        // pre-existing git repository, then the test should make the parent
+        // git repo explicitly. The GIT_CEILING_DIRECTORIES here shouldn't
+        // impact it, since it only prevents git from discovering repositories
+        // at or above the root.
+        command.env(EnvVars::GIT_CEILING_DIRECTORIES, self.root.path());
+        command
+    }
 }
 
 /// Creates a "unified" diff between the two line-oriented strings suitable
